AtomicArc

Struct AtomicArc 

pub struct AtomicArc<T> { /* private fields */ }
A reference-counted, nullable, atomic pointer.

Implementations

Source

impl<T> AtomicArc<T>

pub fn new(data: Option<T>) -> AtomicArc<T>

Create a new AtomicArc.

pub fn from_arc(arc: Option<Arc<T>>) -> AtomicArc<T>

Create a new AtomicArc from an Arc.

pub fn get_arc(&mut self) -> Option<Arc<T>>

Get the value of the pointer as an Arc. This can be done non-atomically since we have a unique reference to the AtomicArc.

pub fn get(&mut self) -> Option<&T>

Get a reference to the value stored in this AtomicArc. This can be done non-atomically since we have a unique reference to the AtomicArc.

pub fn into_arc(self) -> Option<Arc<T>>

Convert this AtomicArc into a plain old Arc

pub fn load(&self, order: Ordering) -> Option<Arc<T>>

Load the value stored in this AtomicArc

pub fn store(&self, new: Option<Arc<T>>, order: Ordering)

Store a new value.

pub fn swap(&self, new: Option<Arc<T>>, order: Ordering) -> Option<Arc<T>>

Atomically swap the value stored in this AtomicArc with the new value, returning the old value.

pub fn compare_and_swap( &self, old: Option<Arc<T>>, new: Option<Arc<T>>, order: Ordering, ) -> Option<Arc<T>>

Atomically swaps the value stored in this AtomicArc if old points to the same Arc as what is currently stored. This does not compare the underlying data, merely that the pointers match. Returns the previous value stored in this AtomicArc, which will be the same as old if the swap was successful.